Developer: s4gor Github: https://github.com/s4gor
Error types for schema-sync
All errors are structured to provide context about what operation failed and why, while maintaining tenant isolation information.
Enums
- Error
- Main error type for schema-sync
Type Aliases
- Result
- Result type alias for schema-sync operations